
# Table of Contents

-   [Install](#org5d56249)
-   [Usage](#org0ead2e5)
    -   [command line](#orgbe03b38)
    -   [api](#orgf3b36d4)

Convert plain text (letters, sometimes numbers, sometimes punctuation) to
obscure characters and cooooool characters from Unicode.


<a id="org5d56249"></a>

# Install

-   requirement: `tyro`
-   `$ pipx install nautc`
-   `$ pip install nautc`


<a id="org0ead2e5"></a>

# Usage


<a id="orgbe03b38"></a>

## command line

    nautc nautc

    usage: nautc.py [-h] [OPTIONS] STR
    
    Convert and print out `text` to obscure but coooool characters. For example:
        # It will only print out funny nautc.
        $> nautc nautc --no_label --dash_length=0
        # It will only print labels.
        $> nautc xx --labels
        # It will return errors.
        $> nautc --labels
    
    ╭─ positional arguments ──────────────────────────────────╮
    │ STR                     text (required)                 │
    ╰─────────────────────────────────────────────────────────╯
    ╭─ options ───────────────────────────────────────────────╮
    │ -h, --help              show this help message and exit │
    │ --no-label, --no-no-label                               │
    │                         (default: False)                │
    │ --labels, --no-labels   (default: False)                │
    │ --dash-length INT       (default: 20)                   │
    ╰─────────────────────────────────────────────────────────╯

<details>

    nautc nautc

    --------------------
    Full Width
    ｎａｕｔｃ
    --------------------
    Math bold Fraktur
    𝖓𝖆𝖚𝖙𝖈
    --------------------
    Math bold script
    𝓷𝓪𝓾𝓽𝓬
    --------------------
    Math monospace
    𝚗𝚊𝚞𝚝𝚌
    --------------------
    Math sans
    𝗇𝖺𝗎𝗍𝖼
    --------------------
    Math sans bold
    𝗻𝗮𝘂𝘁𝗰
    --------------------
    Math sans bold italic
    𝙣𝙖𝙪𝙩𝙘
    --------------------
    Math sans italic
    𝘯𝘢𝘶𝘵𝘤
    --------------------
    A-cute pseudoalphabet
    ńáútć
    --------------------
    Faux Cyrillic pseudoalphabet
    иацтс
    --------------------
    Math Fraktur pseudoalphabet
    𝔫𝔞𝔲𝔱𝔠
    --------------------
    Rock Dots pseudoalphabet
    ṅäüẗċ
    --------------------
    Small Caps pseudoalphabet
    ɴᴀᴜᴛᴄ
    --------------------
    Stroked pseudoalphabet
    nȺᵾŧȼ
    --------------------
    Inverted pseudoalphabet
    uɐnʇɔ
    --------------------
    Inverted pseudoalphabet (backwards)
    ʍ9db7
    --------------------
    Reversed pseudoalphabet
    ᴎAUTↄ
    --------------------
    Reversed pseudoalphabet (backwards)
    W9ꟼp7
    --------------------
    Bubble
    ⓝⓐⓤⓣⓒ
    --------------------
    Small caps
    ɴᴀᴜᴛᴄ
    --------------------
    Currency
    ₦₳Ʉ₮₵
    --------------------
    Double Struck
    𝕟𝕒𝕦𝕥𝕔
    --------------------
    Antrophobia
    иαυт¢
    --------------------
    Invisible Ink
    n҉a҉u҉t҉c҉
    --------------------
    Fraktur
    𝔫𝔞𝔲𝔱𝔠
    --------------------
    Bold Fraktur
    𝖓𝖆𝖚𝖙𝖈
    --------------------
    Paranormal
    nαutc
    --------------------
    Black bubble
    🅝🅐🅤🅣🅒
    --------------------
    Bold Script
    𝓷𝓪𝓾𝓽𝓬
    --------------------
    Hand Writing 1
    𝓃𝒶𝓊𝓉𝒸
    --------------------
    Hand Writing 2
    ɳαυƚƈ
    --------------------
    Symbols
    ♫ꍏ☋☂☾
    --------------------
    Fancy style 1
    ηαυтc
    --------------------
    Fancy style 2
    几卂ㄩㄒ匚
    --------------------
    Fancy style 3
    ŃĂÚŤČ
    --------------------
    Fancy style 4
    ᏁᎪuᏆᏟ
    --------------------
    Fancy style 5
    ᏁᏗᏬᏖፈ
    --------------------
    Fancy style 6
    nɐnʇɔ
    --------------------
    Fancy style 7
    ŇΔỮŦĆ
    --------------------
    Fancy style 8
    ɳαµƭ૮
    --------------------
    Fancy style 9
    ᑎᗩᑌ丅ᑕ
    --------------------
    Fancy style 10
    ภคยtς
    --------------------
    Fancy style 11
    naυтc
    --------------------
    Fancy style 12
    🇳🇦🇺🇹🇨
    --------------------
    Fancy style 13
    ñåɥțç
    --------------------
    Fancy style 14
    ɲąµţȼ
    --------------------
    Fancy style 15
    ῆმυནე
    --------------------
    Fancy style 16
    ŇÃǗŤČ
    --------------------
    Fancy style 17
    ᘉᗅᑗᖶᑤ
    --------------------
    Fancy style 18
    naυтc
    --------------------
    Fancy style 19
    nαutc
    --------------------
    Fancy style 20
    ήάùţς
    --------------------
    Fancy style 21
    ꁹꋫꐇ꓅ꏸ
    --------------------
    Fancy style 22
    ИДυ✞ℂ
    --------------------
    Fancy style 23
    ИДЦΓC
    --------------------
    Fancy style 24
    ռǟʊᏆƈ
    --------------------
    Fancy style 25
    ղɑմԵϲ
    --------------------
    Fancy style 26
    ꈤꍏꀎ꓄ꉓ
    --------------------
    Fancy style 27
    ᴺᴬᵁᵀᶜ
    --------------------
    Fancy style 28
    ꋊꋬ꒤꓄ꉔ
    --------------------
    Fancy style 29
    ЛΛЦŤㄈ
    --------------------
    Fancy style 30
    ƝƛƲƬƇ
    --------------------
    Fancy style 31
    ꋊꁲꐇꋖꀯ
    --------------------
    Fancy style 32
    ꂚꋬꀎ꓄ꏳ
    --------------------
    Fancy style 33
    ՌԹՄԵՇ
    --------------------
    Fancy style 34
    刀ﾑひｲᄃ
    --------------------
    Fancy style 35
    ηαu†ς
    --------------------
    Fancy style 36
    ຖคนt¢
    --------------------
    Fancy style 37
    ŋąųɬƈ
    --------------------
    Fancy style 38
    ᘉᗩᑘᖶᑢ
    --------------------
    Fancy style 39
    ꋊꁲꌈꋖꇃ
    --------------------
    Fancy style 40
    ภᕱuϮ꒝
    --------------------
    Fancy style 41
    ꃔꁲꌈꋖꏳ
    --------------------
    Fancy style 42
    ɴαυтc
    --------------------
    Fancy style 43
    Ոคυ੮८
    --------------------
    Fancy style 44
    ᏁᎪuᏆᏟ
    --------------------
    Fancy style 45
    ꈤꍏꀎ꓄ꉓ
    --------------------
    Fancy style 46
    ክልሁፕር
    --------------------
    Fancy style 47
    ꁹꋫꌇ꓅ꉓ
    --------------------
    Rusify
    пацтc
    --------------------
    Bold
    𝐧𝐚𝐮𝐭𝐜
    --------------------
    Italic
    𝘯𝘢𝘶𝘵𝘤
    --------------------
    Bold Italic
    𝙣𝙖𝙪𝙩𝙘
    --------------------
    Monospace
    𝚗𝚊𝚞𝚝𝚌
    --------------------
    Sorcerer
    ռǟʊȶƈ
    --------------------
    Special
    ᑎᗩᑌTᑕ
    --------------------
    Blurry
    ͏n͏a͏u͏t͏c
    --------------------
    Dirty
    ńäüẗċ
    --------------------
    Knight
    ṆḀṳṮḉ
    --------------------
    Emoji text
    🎵🅰⛎🌴🌜
    --------------------
    H4k3r
    n4u7(
    --------------------
    Fairy
    ᏁᏗᏬᏖፈ
    --------------------
    Square
    🄽🄰🅄🅃🄲
    --------------------
    Thin
    ｎａｕｔｃ
    --------------------
    Tiny
    ɴᴀᴜᴛᴄ
    --------------------
    Upside down
    nɐnʇɔ
    --------------------
    Black square
    🅽🅰🆄🆃🅲
    --------------------
    Magic
    ᏁᎪuᏆᏟ
    --------------------
    Love
    n♥a♥u♥t♥c♥
    --------------------
    Black bracket
    【n】【a】【u】【t】【c】
    --------------------
    White bracket
    『n』『a』『u』『t』『c』
    --------------------
    Strikethrough
    n̶a̶u̶t̶c̶
    --------------------
    Tilde strikethrough
    n̴a̴u̴t̴c̴
    --------------------
    Slash
    n̷a̷u̷t̷c̷
    --------------------
    Underline
    n̲a̲u̲t̲c̲
    --------------------
    Double underline
    n̳a̳u̳t̳c̳
    --------------------
    Stinky
    n̾a̾u̾t̾c̾
    --------------------
    Bridge above
    n͆a͆u͆t͆c͆
    --------------------
    Bridge bellow
    n̺a̺u̺t̺c̺
    --------------------
    Asterisk bellow
    n͙a͙u͙t͙c͙
    --------------------
    Plus sign bellow
    n̟a̟u̟t̟c̟
    --------------------
    x above bellow
    n͓̽a͓̽u͓̽t͓̽c͓̽
    --------------------
    Arrow bellow
    n͎a͎u͎t͎c͎
    --------------------

</details>


<a id="orgf3b36d4"></a>

## api

    from nautc import convert
    for txt in convert("nautc"):
        print(txt)

    ('Full Width', 'ｎａｕｔｃ')
    ('Math bold Fraktur', '𝖓𝖆𝖚𝖙𝖈')
    ('Math bold script', '𝓷𝓪𝓾𝓽𝓬')
    ('Math monospace', '𝚗𝚊𝚞𝚝𝚌')
    ('Math sans', '𝗇𝖺𝗎𝗍𝖼')
    ('Math sans bold', '𝗻𝗮𝘂𝘁𝗰')
    ('Math sans bold italic', '𝙣𝙖𝙪𝙩𝙘')
    ('Math sans italic', '𝘯𝘢𝘶𝘵𝘤')
    ('A-cute pseudoalphabet', 'ńáútć')
    ('Faux Cyrillic pseudoalphabet', 'иацтс')
    ('Math Fraktur pseudoalphabet', '𝔫𝔞𝔲𝔱𝔠')
    ('Rock Dots pseudoalphabet', 'ṅäüẗċ')
    ('Small Caps pseudoalphabet', 'ɴᴀᴜᴛᴄ')
    ('Stroked pseudoalphabet', 'nȺᵾŧȼ')
    ('Inverted pseudoalphabet', 'uɐnʇɔ')
    ('Inverted pseudoalphabet (backwards)', 'ʍ9db7')
    ('Reversed pseudoalphabet', 'ᴎAUTↄ')
    ('Reversed pseudoalphabet (backwards)', 'W9ꟼp7')
    ('Bubble', 'ⓝⓐⓤⓣⓒ')
    ('Small caps', 'ɴᴀᴜᴛᴄ')
    ('Currency', '₦₳Ʉ₮₵')
    ('Double Struck', '𝕟𝕒𝕦𝕥𝕔')
    ('Antrophobia', 'иαυт¢')
    ('Invisible Ink', 'n҉a҉u҉t҉c҉')
    ('Fraktur', '𝔫𝔞𝔲𝔱𝔠')
    ('Bold Fraktur', '𝖓𝖆𝖚𝖙𝖈')
    ('Paranormal', 'nαutc')
    ('Black bubble', '🅝🅐🅤🅣🅒')
    ('Bold Script', '𝓷𝓪𝓾𝓽𝓬')
    ('Hand Writing 1', '𝓃𝒶𝓊𝓉𝒸')
    ('Hand Writing 2', 'ɳαυƚƈ')
    ('Symbols', '♫ꍏ☋☂☾')
    ('Fancy style 1', 'ηαυтc')
    ('Fancy style 2', '几卂ㄩㄒ匚')
    ('Fancy style 3', 'ŃĂÚŤČ')
    ('Fancy style 4', 'ᏁᎪuᏆᏟ')
    ('Fancy style 5', 'ᏁᏗᏬᏖፈ')
    ('Fancy style 6', 'nɐnʇɔ')
    ('Fancy style 7', 'ŇΔỮŦĆ')
    ('Fancy style 8', 'ɳαµƭ૮')
    ('Fancy style 9', 'ᑎᗩᑌ丅ᑕ')
    ('Fancy style 10', 'ภคยtς')
    ('Fancy style 11', 'naυтc')
    ('Fancy style 12', '🇳\u200b🇦\u200b🇺\u200b🇹\u200b🇨\u200b')
    ('Fancy style 13', 'ñåɥțç')
    ('Fancy style 14', 'ɲąµţȼ')
    ('Fancy style 15', 'ῆმυནე')
    ('Fancy style 16', 'ŇÃǗŤČ')
    ('Fancy style 17', 'ᘉᗅᑗᖶᑤ')
    ('Fancy style 18', 'naυтc')
    ('Fancy style 19', 'nαutc')
    ('Fancy style 20', 'ήάùţς')
    ('Fancy style 21', 'ꁹꋫꐇ꓅ꏸ')
    ('Fancy style 22', 'ИДυ✞ℂ')
    ('Fancy style 23', 'ИДЦΓC')
    ('Fancy style 24', 'ռǟʊᏆƈ')
    ('Fancy style 25', 'ղɑմԵϲ')
    ('Fancy style 26', 'ꈤꍏꀎ꓄ꉓ')
    ('Fancy style 27', 'ᴺᴬᵁᵀᶜ')
    ('Fancy style 28', 'ꋊꋬ꒤꓄ꉔ')
    ('Fancy style 29', 'ЛΛЦŤㄈ')
    ('Fancy style 30', 'ƝƛƲƬƇ')
    ('Fancy style 31', 'ꋊꁲꐇꋖꀯ')
    ('Fancy style 32', 'ꂚꋬꀎ꓄ꏳ')
    ('Fancy style 33', 'ՌԹՄԵՇ')
    ('Fancy style 34', '刀ﾑひｲᄃ')
    ('Fancy style 35', 'ηαu†ς')
    ('Fancy style 36', 'ຖคนt¢')
    ('Fancy style 37', 'ŋąųɬƈ')
    ('Fancy style 38', 'ᘉᗩᑘᖶᑢ')
    ('Fancy style 39', 'ꋊꁲꌈꋖꇃ')
    ('Fancy style 40', 'ภᕱuϮ꒝')
    ('Fancy style 41', 'ꃔꁲꌈꋖꏳ')
    ('Fancy style 42', 'ɴαυтc')
    ('Fancy style 43', 'Ոคυ੮८')
    ('Fancy style 44', 'ᏁᎪuᏆᏟ')
    ('Fancy style 45', 'ꈤꍏꀎ꓄ꉓ')
    ('Fancy style 46', 'ክልሁፕር')
    ('Fancy style 47', 'ꁹꋫꌇ꓅ꉓ')
    ('Rusify', 'пацтc')
    ('Bold', '𝐧𝐚𝐮𝐭𝐜')
    ('Italic', '𝘯𝘢𝘶𝘵𝘤')
    ('Bold Italic', '𝙣𝙖𝙪𝙩𝙘')
    ('Monospace', '𝚗𝚊𝚞𝚝𝚌')
    ('Sorcerer', 'ռǟʊȶƈ')
    ('Special', 'ᑎᗩᑌTᑕ')
    ('Blurry', '͏n͏a͏u͏t͏c')
    ('Dirty', 'ńäüẗċ')
    ('Knight', 'ṆḀṳṮḉ')
    ('Emoji text', '🎵🅰⛎🌴🌜')
    ('H4k3r', 'n4u7(')
    ('Fairy', 'ᏁᏗᏬᏖፈ')
    ('Square', '🄽🄰🅄🅃🄲')
    ('Thin', 'ｎａｕｔｃ')
    ('Tiny', 'ɴᴀᴜᴛᴄ')
    ('Upside down', 'nɐnʇɔ')
    ('Black square', '🅽🅰🆄🆃🅲')
    ('Magic', 'ᏁᎪuᏆᏟ')
    ('Love', 'n♥a♥u♥t♥c♥')
    ('Black bracket', '【n】【a】【u】【t】【c】')
    ('White bracket', '『n』『a』『u』『t』『c』')
    ('Strikethrough', 'n̶a̶u̶t̶c̶')
    ('Tilde strikethrough', 'n̴a̴u̴t̴c̴')
    ('Slash', 'n̷a̷u̷t̷c̷')
    ('Underline', 'n̲a̲u̲t̲c̲')
    ('Double underline', 'n̳a̳u̳t̳c̳')
    ('Stinky', 'n̾a̾u̾t̾c̾')
    ('Bridge above', 'n͆a͆u͆t͆c͆')
    ('Bridge bellow', 'n̺a̺u̺t̺c̺')
    ('Asterisk bellow', 'n͙a͙u͙t͙c͙')
    ('Plus sign bellow', 'n̟a̟u̟t̟c̟')
    ('x above bellow', 'n͓̽a͓̽u͓̽t͓̽c͓̽')
    ('Arrow bellow', 'n͎a͎u͎t͎c͎')

    ('Full Width', 'ｎａｕｔｃ')
    ('Math bold Fraktur', '𝖓𝖆𝖚𝖙𝖈')
    ('Math bold script', '𝓷𝓪𝓾𝓽𝓬')
    ('Math monospace', '𝚗𝚊𝚞𝚝𝚌')
    ('Math sans', '𝗇𝖺𝗎𝗍𝖼')
    ('Math sans bold', '𝗻𝗮𝘂𝘁𝗰')
    ('Math sans bold italic', '𝙣𝙖𝙪𝙩𝙘')
    ('Math sans italic', '𝘯𝘢𝘶𝘵𝘤')
    ('A-cute pseudoalphabet', 'ńáútć')
    ('Faux Cyrillic pseudoalphabet', 'иацтс')
    ('Math Fraktur pseudoalphabet', '𝔫𝔞𝔲𝔱𝔠')
    ('Rock Dots pseudoalphabet', 'ṅäüẗċ')
    ('Small Caps pseudoalphabet', 'ɴᴀᴜᴛᴄ')
    ('Stroked pseudoalphabet', 'nȺᵾŧȼ')
    ('Inverted pseudoalphabet', 'uɐnʇɔ')
    ('Inverted pseudoalphabet (backwards)', 'ʍ9db7')
    ('Reversed pseudoalphabet', 'ᴎAUTↄ')
    ('Reversed pseudoalphabet (backwards)', 'W9ꟼp7')
    ('Bubble', 'ⓝⓐⓤⓣⓒ')
    ('Small caps', 'ɴᴀᴜᴛᴄ')
    ('Currency', '₦₳Ʉ₮₵')
    ('Double Struck', '𝕟𝕒𝕦𝕥𝕔')
    ('Antrophobia', 'иαυт¢')
    ('Invisible Ink', 'n҉a҉u҉t҉c҉')
    ('Fraktur', '𝔫𝔞𝔲𝔱𝔠')
    ('Bold Fraktur', '𝖓𝖆𝖚𝖙𝖈')
    ('Paranormal', 'nαutc')
    ('Black bubble', '🅝🅐🅤🅣🅒')
    ('Bold Script', '𝓷𝓪𝓾𝓽𝓬')
    ('Hand Writing 1', '𝓃𝒶𝓊𝓉𝒸')
    ('Hand Writing 2', 'ɳαυƚƈ')
    ('Symbols', '♫ꍏ☋☂☾')
    ('Fancy style 1', 'ηαυтc')
    ('Fancy style 2', '几卂ㄩㄒ匚')
    ('Fancy style 3', 'ŃĂÚŤČ')
    ('Fancy style 4', 'ᏁᎪuᏆᏟ')
    ('Fancy style 5', 'ᏁᏗᏬᏖፈ')
    ('Fancy style 6', 'nɐnʇɔ')
    ('Fancy style 7', 'ŇΔỮŦĆ')
    ('Fancy style 8', 'ɳαµƭ૮')
    ('Fancy style 9', 'ᑎᗩᑌ丅ᑕ')
    ('Fancy style 10', 'ภคยtς')
    ('Fancy style 11', 'naυтc')
    ('Fancy style 12', '🇳\u200b🇦\u200b🇺\u200b🇹\u200b🇨\u200b')
    ('Fancy style 13', 'ñåɥțç')
    ('Fancy style 14', 'ɲąµţȼ')
    ('Fancy style 15', 'ῆმυནე')
    ('Fancy style 16', 'ŇÃǗŤČ')
    ('Fancy style 17', 'ᘉᗅᑗᖶᑤ')
    ('Fancy style 18', 'naυтc')
    ('Fancy style 19', 'nαutc')
    ('Fancy style 20', 'ήάùţς')
    ('Fancy style 21', 'ꁹꋫꐇ꓅ꏸ')
    ('Fancy style 22', 'ИДυ✞ℂ')
    ('Fancy style 23', 'ИДЦΓC')
    ('Fancy style 24', 'ռǟʊᏆƈ')
    ('Fancy style 25', 'ղɑմԵϲ')
    ('Fancy style 26', 'ꈤꍏꀎ꓄ꉓ')
    ('Fancy style 27', 'ᴺᴬᵁᵀᶜ')
    ('Fancy style 28', 'ꋊꋬ꒤꓄ꉔ')
    ('Fancy style 29', 'ЛΛЦŤㄈ')
    ('Fancy style 30', 'ƝƛƲƬƇ')
    ('Fancy style 31', 'ꋊꁲꐇꋖꀯ')
    ('Fancy style 32', 'ꂚꋬꀎ꓄ꏳ')
    ('Fancy style 33', 'ՌԹՄԵՇ')
    ('Fancy style 34', '刀ﾑひｲᄃ')
    ('Fancy style 35', 'ηαu†ς')
    ('Fancy style 36', 'ຖคนt¢')
    ('Fancy style 37', 'ŋąųɬƈ')
    ('Fancy style 38', 'ᘉᗩᑘᖶᑢ')
    ('Fancy style 39', 'ꋊꁲꌈꋖꇃ')
    ('Fancy style 40', 'ภᕱuϮ꒝')
    ('Fancy style 41', 'ꃔꁲꌈꋖꏳ')
    ('Fancy style 42', 'ɴαυтc')
    ('Fancy style 43', 'Ոคυ੮८')
    ('Fancy style 44', 'ᏁᎪuᏆᏟ')
    ('Fancy style 45', 'ꈤꍏꀎ꓄ꉓ')
    ('Fancy style 46', 'ክልሁፕር')
    ('Fancy style 47', 'ꁹꋫꌇ꓅ꉓ')
    ('Rusify', 'пацтc')
    ('Bold', '𝐧𝐚𝐮𝐭𝐜')
    ('Italic', '𝘯𝘢𝘶𝘵𝘤')
    ('Bold Italic', '𝙣𝙖𝙪𝙩𝙘')
    ('Monospace', '𝚗𝚊𝚞𝚝𝚌')
    ('Sorcerer', 'ռǟʊȶƈ')
    ('Special', 'ᑎᗩᑌTᑕ')
    ('Blurry', '͏n͏a͏u͏t͏c')
    ('Dirty', 'ńäüẗċ')
    ('Knight', 'ṆḀṳṮḉ')
    ('Emoji text', '🎵🅰⛎🌴🌜')
    ('H4k3r', 'n4u7(')
    ('Fairy', 'ᏁᏗᏬᏖፈ')
    ('Square', '🄽🄰🅄🅃🄲')
    ('Thin', 'ｎａｕｔｃ')
    ('Tiny', 'ɴᴀᴜᴛᴄ')
    ('Upside down', 'nɐnʇɔ')
    ('Black square', '🅽🅰🆄🆃🅲')
    ('Magic', 'ᏁᎪuᏆᏟ')
    ('Love', 'n♥a♥u♥t♥c♥')
    ('Black bracket', '【n】【a】【u】【t】【c】')
    ('White bracket', '『n』『a』『u』『t』『c』')
    ('Strikethrough', 'n̶a̶u̶t̶c̶')
    ('Tilde strikethrough', 'n̴a̴u̴t̴c̴')
    ('Slash', 'n̷a̷u̷t̷c̷')
    ('Underline', 'n̲a̲u̲t̲c̲')
    ('Double underline', 'n̳a̳u̳t̳c̳')
    ('Stinky', 'n̾a̾u̾t̾c̾')
    ('Bridge above', 'n͆a͆u͆t͆c͆')
    ('Bridge bellow', 'n̺a̺u̺t̺c̺')
    ('Asterisk bellow', 'n͙a͙u͙t͙c͙')
    ('Plus sign bellow', 'n̟a̟u̟t̟c̟')
    ('x above bellow', 'n͓̽a͓̽u͓̽t͓̽c͓̽')
    ('Arrow bellow', 'n͎a͎u͎t͎c͎')

